@@ -5,6 +5,7 @@ import asyncio
 import json
 import time
 import socket
+import urllib.parse
 import random
 from NetUtils import ClientStatus
 from CommonClient import CommonContext, get_base_parser, server_loop
@@ -36,12 +37,12 @@ class DSTContext(CommonContext):
     locations_hinted = set()
     _eventqueue:List[Dict] = []
 
-    def __init__(self, server_address, slot_name, password, ready_callback=None, error_callback=None):
+    def __init__(self, server_address, password, ready_callback=None, error_callback=None):
         self.dst_handler = DSTHandler(self)
         super().__init__(server_address, password)
         self.ready_callback = ready_callback
         self.error_callback = error_callback
-        self.username = slot_name
+        self.username = urllib.parse.urlparse(server_address).username
         
         if self.ready_callback:
             from kivy.clock import Clock
@@ -859,7 +860,7 @@ class DSTHandler():
             await asyncio.sleep(5.0)
 
 
-def launch(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None, slot_name: str = None):
+def launch(server_address: str = None, password: str = None, ready_callback=None, error_callback=None, slot_name: str = None):
     """
     Launch the client
     """
@@ -867,7 +868,7 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
     logger = logging.getLogger("DontStarveTogetherClient")
 
     async def main():
-        ctx = DSTContext(server_address, slot_name, password, ready_callback, error_callback)
+        ctx = DSTContext(server_address, password, ready_callback, error_callback)
         if ctx._can_takeover_existing_gui():
             await ctx._takeover_existing_gui() 
         else:
@@ -902,6 +903,6 @@ def launch(server_address: str = None, slot_name: str = None, password: str = No
             error_callback()
 
 
-def main(server_address: str = None, slot_name: str = None, password: str = None, ready_callback=None, error_callback=None):
+def main(server_address: str = None, password: str = None, ready_callback=None, error_callback=None):
     """Main entry point for integration with MultiWorld system"""
-    launch(server_address, slot_name, password, ready_callback, error_callback)
+    launch(server_address, password, ready_callback, error_callback)
