@@ -1,8 +1,7 @@
 from . import DSTWorld, DSTWeb
-from .Client import launch
 
 """
-Don World Registration
+Don't Starve Together World Registration
 
 This file contains the metadata and class references for the dontstarvetogether world.
 """
@@ -20,4 +19,4 @@ VERSION = version
 # Plugin entry points
 WORLD_CLASS = DSTWorld
 WEB_WORLD_CLASS = DSTWeb
-CLIENT_FUNCTION = launch
+CLIENT_FUNCTION = None
